@@ -39,6 +39,7 @@ def Cardano(a, b, c, d):
         v *= J
     return u+v-z0, u*J+v*Jc-z0, u*Jc+v*J-z0
 
+
 class AncestorGraph(BaseGraph):
     """
     This class enables setting up ancestor graphs and save them
@@ -103,6 +104,7 @@ class AncestorGraph(BaseGraph):
                     self.select_individuals(
                         mother, generations - 1, filter=filter)
             # family.visible_children.sort()
+
     def place_selected_individuals(self, individual, child_family, spouse_family, child_of_family, x_offset=0):
         """
         Place the graphical representations in direction of x
@@ -145,7 +147,7 @@ class AncestorGraph(BaseGraph):
             individual.graphical_representations[0].set_x_position(
                 x_position, spouse_family)
             # if child_of_family :# and len(child_of_family.graphical_representations[0].visible_children) > 1:
-            if child_of_family and not child_of_family.family_id in individual.graphical_representations[0].get_x_position():
+            if child_of_family and child_of_family.family_id not in individual.graphical_representations[0].get_x_position():
                 individual.graphical_representations[0].set_x_position(
                     x_position, child_of_family, True)
             x_position += 1
@@ -156,12 +158,12 @@ class AncestorGraph(BaseGraph):
         else:
             for _, _, sibling in sorted(child_of_family.graphical_representations[0].visible_children.values()):
                 if sibling.individual_id == individual.individual_id:
-                    if not sibling.graphical_representations[0].get_x_position() or not child_of_family.family_id in sibling.graphical_representations[0].get_x_position():
+                    if not sibling.graphical_representations[0].get_x_position() or child_of_family.family_id not in sibling.graphical_representations[0].get_x_position():
                         pass
                         # sibling.graphical_representations[0].set_x_position(x_position - 1, child_of_family)
                         # x_position += 1
                 else:
-                    if not sibling.graphical_representations[0].get_x_position() or not child_of_family.family_id in sibling.graphical_representations[0].get_x_position():
+                    if not sibling.graphical_representations[0].get_x_position() or child_of_family.family_id not in sibling.graphical_representations[0].get_x_position():
                         if not sibling.graphical_representations[0].visual_placement_child:
                             sibling.graphical_representations[
                                 0].visual_placement_child = individual.graphical_representations[0].visual_placement_child
@@ -235,19 +237,20 @@ class AncestorGraph(BaseGraph):
                         0, individual.graphical_representations[0].x_end - individual.graphical_representations[0].x_start)
                     sibling.graphical_representations[0].range[child_family] = (
                         individual.graphical_representations[0].x_start, individual.graphical_representations[0].x_end)
-        min_ordinal = 9e99
-        max_ordinal = -9e99
-        for graphical_individual_representation in self.graphical_individual_representations:
-            birth_event = graphical_individual_representation.get_birth_event()
-            if not birth_event:
-                continue
-            birth_ordinal_value = birth_event['ordinal_value']
-            death_event = graphical_individual_representation.get_death_event()
-            death_ordinal_value = death_event['ordinal_value']
-            min_ordinal = min(min_ordinal, birth_ordinal_value)
-            max_ordinal = max(max_ordinal, death_ordinal_value)
-        self.min_ordinal = min_ordinal-3000
-        self.max_ordinal = max_ordinal+3000
+        if len(self.graphical_individual_representations) > 0:
+            min_ordinal = 9e99
+            max_ordinal = -9e99
+            for graphical_individual_representation in self.graphical_individual_representations:
+                birth_event = graphical_individual_representation.get_birth_event()
+                if not birth_event:
+                    continue
+                birth_ordinal_value = birth_event['ordinal_value']
+                death_event = graphical_individual_representation.get_death_event()
+                death_ordinal_value = death_event['ordinal_value']
+                min_ordinal = min(min_ordinal, birth_ordinal_value)
+                max_ordinal = max(max_ordinal, death_ordinal_value)
+            self.min_ordinal = min_ordinal-3000
+            self.max_ordinal = max_ordinal+3000
 
     def _compress_single_individual_position(self, individual, cof, direction):
         """
@@ -260,9 +263,8 @@ class AncestorGraph(BaseGraph):
                 self._move_single_individual(individual, cof, direction)
                 self._check_compressed_x_position(True)
         except LifeLineChartCollisionDetected:
-            pass        
+            pass
         self._move_single_individual(individual, cof, - direction)
-            
 
     def _compress_graph_ancestor_graph(self, graphical_family_representation):
         """
@@ -280,37 +282,42 @@ class AncestorGraph(BaseGraph):
         x_pos_wife = None
         if graphical_family_representation.husb is not None and graphical_family_representation.husb.has_graphical_representation():
             x_pos_husb = graphical_family_representation.husb.graphical_representations[0].get_x_position()[
-                               graphical_family_representation.family_id][1]
+                graphical_family_representation.family_id][1]
             individuals.append((1, graphical_family_representation.husb))
         if graphical_family_representation.wife is not None and graphical_family_representation.wife.has_graphical_representation():
             x_pos_wife = graphical_family_representation.wife.graphical_representations[0].get_x_position()[
-                            graphical_family_representation.family_id][1]
+                graphical_family_representation.family_id][1]
             individuals.append((-1, graphical_family_representation.wife))
         if x_pos_husb and x_pos_wife and x_pos_husb > x_pos_wife:
             family_was_flipped = True
-        
-        for index, (_, individual) in enumerate(sorted(individuals)):
+
+        for _, individual in sorted(individuals):
             cofs = individual.get_child_of_family()
             for cof in cofs:
                 if cof.has_graphical_representation():
                     if cof.husb is None or cof.wife is None \
                             or not cof.husb.has_graphical_representation() \
                             or not cof.wife.has_graphical_representation():
-                        this_individual_x_pos = individual.graphical_representations[0].get_x_position()[cof.family_id][1]
+                        this_individual_x_pos = individual.graphical_representations[0].get_x_position()[
+                            cof.family_id][1]
                         parent_x_pos = None
                         if cof.husb is not None and cof.husb.has_graphical_representation():
-                            parent_x_pos = cof.husb.graphical_representations[0].get_x_position()[cof.family_id][1]
+                            parent_x_pos = cof.husb.graphical_representations[0].get_x_position()[
+                                cof.family_id][1]
                         if cof.wife is not None and cof.wife.has_graphical_representation():
-                            parent_x_pos = cof.wife.graphical_representations[0].get_x_position()[cof.family_id][1]
+                            parent_x_pos = cof.wife.graphical_representations[0].get_x_position()[
+                                cof.family_id][1]
                         if parent_x_pos is not None and this_individual_x_pos > parent_x_pos:
-                            self._compress_single_individual_position(individual, cof, -1)
+                            self._compress_single_individual_position(
+                                individual, cof, -1)
                             # self._move_single_individual(individual, cof, parent_x_pos - this_individual_x_pos + 1)
                         elif parent_x_pos is not None and this_individual_x_pos < parent_x_pos:
-                            self._compress_single_individual_position(individual, cof, 1)
+                            self._compress_single_individual_position(
+                                individual, cof, 1)
                             # self._move_single_individual(individual, cof, parent_x_pos - this_individual_x_pos - 1)
                     self._compress_graph_ancestor_graph(
                         cof.graphical_representations[0])
-        for index, (original_direction_factor, individual) in enumerate(sorted(individuals)):
+        for original_direction_factor, individual in sorted(individuals):
             if individual is None:
                 continue
             i = 0
@@ -322,7 +329,7 @@ class AncestorGraph(BaseGraph):
             self.compression_steps -= 1
             if self.compression_steps <= 0:
                 continue
-            
+
             if not individual.graphical_representations[0].visible_parent_family or not individual.graphical_representations[0].visible_parent_family.family_id in individual.graphical_representations[0].get_x_position():
                 # try:
                 #     while i < 50000:
@@ -359,7 +366,7 @@ class AncestorGraph(BaseGraph):
                 pass
             if i != 0:
                 logger.info('moved ' + ' '.join(individual.name) +
-                      ' by ' + str(i * direction_factor * 1))
+                            ' by ' + str(i * direction_factor * 1))
 
     def modify_layout(self, root_individual_id):
         """
@@ -393,7 +400,7 @@ class AncestorGraph(BaseGraph):
             items = list(reversed(sorted([(child.graphical_representations[0].get_birth_event()[
                          'ordinal_value'], index, child) for index, child in enumerate(candidantes)])))
             failed = []
-            for ov, index, child in items:
+            for ov, _, child in items:
                 c_pos = list(
                     child.graphical_representations[0].get_x_position().values())[1:]
                 for x_pos in c_pos:
@@ -405,7 +412,7 @@ class AncestorGraph(BaseGraph):
                     failed, _, _ = self.check_unique_x_position()
                     if len(failed) > 0:
                         logger.error("failed flipping " +
-                              str((x_pos[2].family_id, ov)))
+                                     str((x_pos[2].family_id, ov)))
                         break
                     new_width, _ = self._calculate_sum_of_distances()
                     if new_width > width:
@@ -430,15 +437,19 @@ class AncestorGraph(BaseGraph):
                 'i', root_individual_id)].graphical_representations[0].visible_parent_family)
 
             # compressed graph should be aligned left
-            _, min_index_x, max_index_x, self.position_to_person_map = self._check_compressed_x_position(False)
-            self._move_individual_and_ancestors(self._instances[('i',root_individual_id)], sorted(list(self._instances[('i',root_individual_id)].graphical_representations[0].get_x_position().values()))[0][2], -(min_index_x-old_x_min_index)*1)
+            _, min_index_x, max_index_x, self.position_to_person_map = self._check_compressed_x_position(
+                False)
+            self._move_individual_and_ancestors(self._instances[('i', root_individual_id)], sorted(list(self._instances[(
+                'i', root_individual_id)].graphical_representations[0].get_x_position().values()))[0][2], -(min_index_x-old_x_min_index)*1)
             keys = sorted(list(self.position_to_person_map.keys()))
             for key in keys:
-                self.position_to_person_map[key - (old_x_min_index - min_index_x) * 1] = self.position_to_person_map.pop(key)
+                self.position_to_person_map[key - (
+                    old_x_min_index - min_index_x) * 1] = self.position_to_person_map.pop(key)
             width = (max_index_x - min_index_x)
             self.min_x_index = 0
             self.max_x_index = width
-            logger.info(f"compression reduced the total width by {width - old_width} (i.e. from {old_width} to {width})")
+            logger.info(
+                f"compression reduced the total width by {width - old_width} (i.e. from {old_width} to {width})")
         else:
             _, _, _, self.position_to_person_map = self._check_compressed_x_position(
                 False)
@@ -466,7 +477,16 @@ class AncestorGraph(BaseGraph):
         self.additional_graphical_items = {}
         self.additional_graphical_items['grid'] = []
 
-        font_size = self._formatting['font_size_description']*self._formatting['relative_line_thickness']*self._formatting['vertical_step_size']
+        font_size = self._formatting['font_size_description'] * \
+            self._formatting['relative_line_thickness'] * \
+            self._formatting['vertical_step_size']
+
+        if len(self.graphical_individual_representations) == 0:
+            # settings for empty graphs
+            self.min_x_index = 0
+            self.max_x_index = 1
+            self.min_ordinal = datetime.date(1900,1,1).toordinal()
+            self.max_ordinal = datetime.date(2000,1,1).toordinal()
 
         # setup grid
         max_y = max(self._map_y_position(self.min_ordinal),
@@ -512,8 +532,8 @@ class AncestorGraph(BaseGraph):
         for index in range(1000):
             x_position = index*100
             if x_position > min_x_index and x_position < max_x_index:
-                svg_path = Path(
-                    Line(x_position + min_y*1j, x_position + max_y*1j))
+                # svg_path = Path(
+                #     Line(x_position + min_y*1j, x_position + max_y*1j))
                 if index % 20 == 0:
                     for index2 in range(600):
                         year = 1000 + 2*index2
@@ -558,6 +578,9 @@ class AncestorGraph(BaseGraph):
             for _, x_position in x_positions.items():
                 min_x_index = min(min_x_index, x_position[1])
                 max_x_index = max(max_x_index, x_position[1])
+        if len(self.graphical_individual_representations) == 0:
+            min_x_index = 0
+            max_x_index = 0
         self.min_x_index = min_x_index  # -1000
         self.max_x_index = max_x_index + 1  # +200
 
@@ -616,7 +639,7 @@ class AncestorGraph(BaseGraph):
                                                        graphical_representation_marriage_family.family_id][1])
                             except:
                                 logger.error('something went wrong with ' + "".join(visible_child.name) +
-                                      ". The position family 0 is not equal to the placement...")
+                                             ". The position family 0 is not equal to the placement...")
                         if len(child_x_indices) > 0:
                             # calculate the middle over the children
                             marriage_ring_positions.append(self._map_position(
@@ -639,7 +662,6 @@ class AncestorGraph(BaseGraph):
                     marriage_labels.append(
                         str(graphical_representation_marriage_family.label))
 
-
             # generate event node information
             knots = []
             _birth_original_location = (
@@ -650,7 +672,6 @@ class AncestorGraph(BaseGraph):
             _death_position = self._map_position(*_death_original_location)
             knots.append((x_pos_list[0][1], birth_event['ordinal_value']))
             images = []
-            import os
             for index, (marriage_ring_index, marriage_ordinal, new_x_index_after_marriage, label) in enumerate(zip(marriage_ring_indices, marriage_ordinals, new_x_indices_after_marriage, marriage_labels)):
                 if not self._formatting['no_ring']:
                     ring_position = self._map_position(
@@ -675,20 +696,22 @@ class AncestorGraph(BaseGraph):
                     dy_line = self._inverse_y_position(
                         self._formatting['relative_line_thickness']*self._formatting['vertical_step_size']) - self._inverse_y_position(0)
                     for index, line in enumerate(label.split('\n')):
-                        position = self._map_position(marriage_ring_index, marriage_ordinal + dy_line)
-                        position = (position[0], position[1] + (index + 0.2) * font_size * 1.2)
+                        position = self._map_position(
+                            marriage_ring_index, marriage_ordinal + dy_line)
+                        position = (position[0], position[1] +
+                                    (index + 0.2) * font_size * 1.2)
                         images.append({
-                                'type': 'text',
-                                'config': {
+                            'type': 'text',
+                            'config': {
                                     'style': f"font-size:{font_size}px;font-family:{self._formatting['font_name']}",
                                     'text': line,
                                     'text-anchor': 'middle',
                                     # 'align' : 'center',
                                     'insert': position,
-                                },
-                                'font_size': font_size,
-                                'font_name': self._formatting['font_name'],
-                            })
+                            },
+                            'font_size': font_size,
+                            'font_name': self._formatting['font_name'],
+                        })
                 knots.append((marriage_ring_index, marriage_ordinal))
                 if len(marriage_ordinals) > index + 1:
                     # zwischenpunkt zur ursprungsposition
@@ -698,7 +721,7 @@ class AncestorGraph(BaseGraph):
 
             Path_types = {
                 'Line': Line,
-                'CubicBezier':CubicBezier
+                'CubicBezier': CubicBezier
             }
             # for ov, filename in graphical_individual_representation.individual.images.items():
             #     foto_size = self._formatting['individual_foto_relative_size'] * self._formatting['relative_line_thickness'] * self._formatting['vertical_step_size']
@@ -747,36 +770,42 @@ class AncestorGraph(BaseGraph):
                     )
                     if len(graphical_individual_representation.individual.images) > 0:
                         index = 0
-                        svg_path = Path_types[data[-1][0]['type']](*data[-1][0]['arguments'])
+                        svg_path = Path_types[data[-1][0]
+                                              ['type']](*data[-1][0]['arguments'])
                         for ov, filename in graphical_individual_representation.individual.images.items():
                             if ov >= knots[index][1] and ov <= knots[index + 1][1]:
-                                foto_size = self._formatting['individual_foto_relative_size'] * self._formatting['relative_line_thickness'] * self._formatting['vertical_step_size']
-                                foto_size_y = self._map_y_position(self._inverse_x_position(foto_size))
+                                foto_size = self._formatting['individual_foto_relative_size'] * \
+                                    self._formatting['relative_line_thickness'] * \
+                                    self._formatting['vertical_step_size']
+                                # foto_size_y = self._map_y_position(self._inverse_x_position(foto_size))
                                 # xpos = svg_path.intersect(Line(coordinate_transformation(min(knots[index][0],knots[index + 1][0])-1, ov), coordinate_transformation(max(knots[index][0],knots[index + 1][0])+1, ov)))[0]
                                 # xpos = svg_path.point(xpos[0])
                                 if type(svg_path) == Line:
-                                    xpos = svg_path.start.real + self._map_y_position(ov)*1j
+                                    xpos = svg_path.start.real + \
+                                        self._map_y_position(ov)*1j
                                 else:
                                     coeffs = svg_path.poly()
-                                    coeffs2 = (coeffs[0].imag, coeffs[1].imag, coeffs[2].imag, coeffs[3].imag - self._map_y_position(ov))
+                                    coeffs2 = (
+                                        coeffs[0].imag, coeffs[1].imag, coeffs[2].imag, coeffs[3].imag - self._map_y_position(ov))
                                     roots = Cardano(*coeffs2)
-                                    root = [root.real for root in roots if abs(root.imag) < 1e-10][0]
+                                    root = [root.real for root in roots if abs(
+                                        root.imag) < 1e-10][0]
                                     if len(root) > 0:
                                         xpos = svg_path.point(root[0])
                                     else:
                                         xpos = svg_path.point(roots[1])
                                 images.append(
-                                        {
-                                            'type': 'image',
-                                            'config': {
+                                    {
+                                        'type': 'image',
+                                        'config': {
                                                 'insert': (
                                                     xpos.real - foto_size/2,
                                                     xpos.imag - foto_size/2),
-                                                'size': (foto_size,foto_size),
-                                            },
-                                            'filename': filename
-                                        }
-                                    )
+                                                'size': (foto_size, foto_size),
+                                        },
+                                        'filename': filename
+                                    }
+                                )
                     # for ov, filename in graphical_individual_representation.individual.images.items():
                     #     if ov > knots[0][1] and ov < knots[1][1]:
                     #         foto_size = self._formatting['individual_foto_relative_size'] * self._formatting['relative_line_thickness'] * self._formatting['vertical_step_size']
@@ -801,8 +830,10 @@ class AncestorGraph(BaseGraph):
                             data.append(
                                 ({'type': 'CubicBezier', 'arguments': (
                                     coordinate_transformation(*interp(0, 0)),
-                                    coordinate_transformation(*interp(0, 1)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.0, 0.7)),
-                                    coordinate_transformation(*interp(0, 1)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.5, 0.9)),
+                                    coordinate_transformation(
+                                        *interp(0, 1)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.0, 0.7)),
+                                    coordinate_transformation(
+                                        *interp(0, 1)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.5, 0.9)),
                                     coordinate_transformation(*interp(1, 1)),
                                 )},
                                     # ((knots[index][1]-_birth_position[1])/(self._map_y_position(self._formatting['fade_individual_color_black_age']*365+birth_event['ordinal_value'])-_birth_position[1]), (knots[index+1][1]-_birth_position[1])/(self._map_y_position(self._formatting['fade_individual_color_black_age']*365+birth_event['ordinal_value'])-_birth_position[1])),
@@ -814,8 +845,10 @@ class AncestorGraph(BaseGraph):
                             data.append(
                                 ({'type': 'CubicBezier', 'arguments': (
                                     coordinate_transformation(*interp(0, 0)),
-                                    coordinate_transformation(*interp(1, 0)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.8, 0)),
-                                    coordinate_transformation(*interp(1, 0)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(1, 0.2)),
+                                    coordinate_transformation(
+                                        *interp(1, 0)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.8, 0)),
+                                    coordinate_transformation(
+                                        *interp(1, 0)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(1, 0.2)),
                                     coordinate_transformation(*interp(1, 1)),
                                 )},
                                     # ((knots[index][1]-_birth_position[1])/(self._map_y_position(self._formatting['fade_individual_color_black_age']*365+birth_event['ordinal_value'])-_birth_position[1]), (knots[index+1][1]-_birth_position[1])/(self._map_y_position(self._formatting['fade_individual_color_black_age']*365+birth_event['ordinal_value'])-_birth_position[1])),
@@ -824,37 +857,43 @@ class AncestorGraph(BaseGraph):
                                 )
                             )
                         if len(graphical_individual_representation.individual.images) > 0:
-                            svg_path = Path_types[data[-1][0]['type']](*data[-1][0]['arguments'])
+                            svg_path = Path_types[data[-1][0]
+                                                  ['type']](*data[-1][0]['arguments'])
                             for ov, filename in graphical_individual_representation.individual.images.items():
                                 if ov > knots[index][1] and ov < knots[index + 1][1]:
-                                    foto_size = self._formatting['individual_foto_relative_size'] * self._formatting['relative_line_thickness'] * self._formatting['vertical_step_size']
-                                    foto_size_y = self._map_y_position(self._inverse_x_position(foto_size))
+                                    foto_size = self._formatting['individual_foto_relative_size'] * \
+                                        self._formatting['relative_line_thickness'] * \
+                                        self._formatting['vertical_step_size']
+                                    # foto_size_y = self._map_y_position(self._inverse_x_position(foto_size))
                                     # xpos = svg_path.intersect(Line(coordinate_transformation(min(knots[index][0],knots[index + 1][0])-1, ov), coordinate_transformation(max(knots[index][0],knots[index + 1][0])+1, ov)))[0]
                                     # xpos = svg_path.point(xpos[0])
                                     if type(svg_path) == Line:
-                                        xpos = svg_path.start.real + self._map_y_position(ov)*1j
+                                        xpos = svg_path.start.real + \
+                                            self._map_y_position(ov)*1j
                                     else:
                                         coeffs = svg_path.poly()
-                                        coeffs2 = (coeffs[0].imag, coeffs[1].imag, coeffs[2].imag, coeffs[3].imag - self._map_y_position(ov))
-                                        #coeffs2 = (coeffs[0] - self._map_y_position(ov)*1j, coeffs[1], coeffs[2], coeffs[3])
+                                        coeffs2 = (
+                                            coeffs[0].imag, coeffs[1].imag, coeffs[2].imag, coeffs[3].imag - self._map_y_position(ov))
+                                        # coeffs2 = (coeffs[0] - self._map_y_position(ov)*1j, coeffs[1], coeffs[2], coeffs[3])
                                         roots = Cardano(*coeffs2)
-                                        root = [root.real for root in roots if abs(root.imag) < 1e-10 and root.real >= 0 and root.real <= 1]
+                                        root = [root.real for root in roots if abs(
+                                            root.imag) < 1e-10 and root.real >= 0 and root.real <= 1]
                                         if len(root) > 0:
                                             xpos = svg_path.point(root[0])
                                         else:
                                             xpos = svg_path.point(roots[1])
                                     images.append(
-                                            {
-                                                'type': 'image',
-                                                'config': {
+                                        {
+                                            'type': 'image',
+                                            'config': {
                                                     'insert': (
                                                         xpos.real - foto_size/2,
                                                         xpos.imag - foto_size/2),
-                                                    'size': (foto_size,foto_size),
-                                                },
-                                                'filename': filename
-                                            }
-                                        )
+                                                    'size': (foto_size, foto_size),
+                                            },
+                                            'filename': filename
+                                        }
+                                    )
             life_line_bezier_paths = []
             marriage_bezier(images, life_line_bezier_paths, knots)
 
@@ -924,6 +963,7 @@ class AncestorGraph(BaseGraph):
                     }
                 )
             graphical_individual_representation.items += images
+
     def paint_and_save(self, individual_id, filename=None):
         """
         setup svg file and save it.
@@ -934,10 +974,10 @@ class AncestorGraph(BaseGraph):
         """
 
         logger.debug('start creating document')
-        max_y = max(self._map_y_position(self.min_ordinal),
-                    self._map_y_position(self.max_ordinal))
-        min_y = min(self._map_y_position(self.min_ordinal),
-                    self._map_y_position(self.max_ordinal))
+        # max_y = max(self._map_y_position(self.min_ordinal),
+        #             self._map_y_position(self.max_ordinal))
+        # min_y = min(self._map_y_position(self.min_ordinal),
+        #             self._map_y_position(self.max_ordinal))
 
         # drawing = svg2rlg("file.svg")
         if filename is None:
@@ -961,7 +1001,6 @@ class AncestorGraph(BaseGraph):
 
         from PIL import Image
         import base64
-        import os
 
         image_defs = {}
         additional_items = []
@@ -971,7 +1010,7 @@ class AncestorGraph(BaseGraph):
                               for index, gr in enumerate(self.graphical_individual_representations)]
         sorted_individuals.sort()
         sorted_individual_items = []
-        for _, index, graphical_individual_representation in sorted_individuals:
+        for _, _, graphical_individual_representation in sorted_individuals:
             sorted_individual_items += graphical_individual_representation.items
 
         for item in additional_items + sorted_individual_items:
@@ -1037,7 +1076,8 @@ class AncestorGraph(BaseGraph):
                     pos_y = item['config']['insert'][1]
                     width = item['config']['size'][0]
                     height = item['config']['size'][1]
-                    key = 'image_' + str(width) + '_' + str(height) + item['filename']
+                    key = 'image_' + str(width) + '_' + \
+                        str(height) + item['filename']
                     if key in image_defs:
                         this_def = image_defs[key]
                     else:
